@@ -31,6 +31,7 @@ from .helper import (
         get_file_doubles_from_fake_file_scenarios,
         make_fake_file_scenarios,
         make_unique_slug,
+        patch_locale_getpreferredencoding,
         patch_os_stat,
         patch_system_interfaces,
         setup_file_double_behaviour,
@@ -121,7 +122,6 @@ def make_changes_document(fields, upload_params_by_name=None):
         :param upload_params_by_name: Mapping from filename to upload
             parameters for each file.
         :return: The changes document as an RFC 822 formatted text.
-
         """
     document_fields = fields.copy()
     if upload_params_by_name is not None:
@@ -163,6 +163,19 @@ def make_changes_file_scenarios():
             """))
     fake_file_with_format = io.StringIO(textwrap.dedent("""\
             Format: FOO
+            Changed-By: Dolor sit amet <dolor@example.org>
+            Files:
+                Lorem ipsum dolor sit amet
+            """))
+    fake_file_accented_text = io.StringIO(textwrap.dedent("""\
+            Format: FOO
+            Changed-By: Dølòr sít ämêt <dolor@example.org>
+            Files:
+                Lorem ipsum dolor sit amet
+            """))
+    fake_file_olditalic_text = io.StringIO(textwrap.dedent("""\
+            Format: FOO
+            Changed-By: 𐌃𐌏𐌋𐌏𐌓 𐌔𐌉𐌕 𐌀𐌌𐌄𐌕 <dolor@example.org>
             Files:
                 Lorem ipsum dolor sit amet
             """))
@@ -171,6 +184,12 @@ def make_changes_file_scenarios():
             Files:
                 FOO BAR
             """))
+    fake_file_needs_utf8 = io.StringIO(textwrap.dedent("""\
+            # ქართული
+            # 你好
+            Files:
+                Lórem ipsüm dolôr sìt āmet
+            """))
 
     scenarios = [
             ('no-format', {
@@ -194,6 +213,25 @@ def make_changes_file_scenarios():
                     path=file_path,
                     fake_file=fake_file_with_format),
                 'expected_result': make_changes_document({
+                    'changed-by': "Dolor sit amet <dolor@example.org>",
+                    'files': "Lorem ipsum dolor sit amet",
+                    }),
+                }),
+            ('non-ascii', {
+                'file_double': FileDouble(
+                    path=file_path,
+                    fake_file=fake_file_accented_text),
+                'expected_result': make_changes_document({
+                    'changed-by': "Dølòr sít ämêt <dolor@example.org>",
+                    'files': "Lorem ipsum dolor sit amet",
+                    }),
+                }),
+            ('higher-character-plane', {
+                'file_double': FileDouble(
+                    path=file_path,
+                    fake_file=fake_file_olditalic_text),
+                'expected_result': make_changes_document({
+                    'changed-by': "𐌃𐌏𐌋𐌏𐌓 𐌔𐌉𐌕 𐌀𐌌𐌄𐌕 <dolor@example.org>",
                     'files': "Lorem ipsum dolor sit amet",
                     }),
                 }),
@@ -208,6 +246,14 @@ def make_changes_file_scenarios():
                     fake_file=fake_file_invalid),
                 'expected_error': FakeSystemExit,
                 }),
+            ('encoding needs-utf8', {
+                'file_double': FileDouble(
+                    path=file_path,
+                    fake_file=fake_file_needs_utf8),
+                'expected_result': make_changes_document({
+                    'files': "Lórem ipsüm dolôr sìt āmet",
+                    }),
+                }),
             ]
 
     for (scenario_name, scenario) in scenarios:
@@ -609,10 +655,8 @@ class source_check_TestCase(
             self.assertNotIn(message_lead, sys.stdout.getvalue())
 
 
-class verify_files_TestCase(
-        testscenarios.WithScenarios,
-        testtools.TestCase):
-    """ Test cases for `verify_files` function. """
+class verify_files_BaseTestCase(testtools.TestCase):
+    """ Base for test cases for `verify_files` function. """
 
     default_args = dict(
             host="foo",
@@ -622,36 +666,6 @@ class verify_files_TestCase(
             debug=None,
             )
 
-    scenarios = [
-            ('default', {}),
-            ('binary-only', {
-                'check_upload_variant_return_value': False,
-                }),
-            ('include foo.tar.gz', {
-                'additional_file_suffixes': [".tar.gz"],
-                'source_check_result': SourceCheckResult(
-                    include_orig=False, include_tar=True),
-                }),
-            ('include foo.orig.tar.gz', {
-                'additional_file_suffixes': [".orig.tar.gz"],
-                'source_check_result': SourceCheckResult(
-                    include_orig=True, include_tar=False),
-                }),
-            ('unexpected foo.tar.gz', {
-                'additional_file_suffixes': [".tar.gz"],
-                'expected_rejection_message': (
-                    "Package includes a .tar.gz file although"),
-                }),
-            ('unexpected foo.orig.tar.gz', {
-                'additional_file_suffixes': [".orig.tar.gz"],
-                'expected_rejection_message': (
-                    "Package includes an .orig.tar.gz file although"),
-                }),
-            ('no distribution', {
-                'test_distribution': None,
-                }),
-            ]
-
     def setUp(self):
         """ Set up test fixtures. """
         super().setUp()
@@ -794,6 +808,42 @@ class verify_files_TestCase(
         else:
             self.expected_source_control_file_path = ""
 
+
+class verify_files_TestCase(
+        testscenarios.WithScenarios,
+        verify_files_BaseTestCase):
+    """ Test cases for `verify_files` function. """
+
+    scenarios = [
+            ('default', {}),
+            ('binary-only', {
+                'check_upload_variant_return_value': False,
+                }),
+            ('include foo.tar.gz', {
+                'additional_file_suffixes': [".tar.gz"],
+                'source_check_result': SourceCheckResult(
+                    include_orig=False, include_tar=True),
+                }),
+            ('include foo.orig.tar.gz', {
+                'additional_file_suffixes': [".orig.tar.gz"],
+                'source_check_result': SourceCheckResult(
+                    include_orig=True, include_tar=False),
+                }),
+            ('unexpected foo.tar.gz', {
+                'additional_file_suffixes': [".tar.gz"],
+                'expected_rejection_message': (
+                    "Package includes a .tar.gz file although"),
+                }),
+            ('unexpected foo.orig.tar.gz', {
+                'additional_file_suffixes': [".orig.tar.gz"],
+                'expected_rejection_message': (
+                    "Package includes an .orig.tar.gz file although"),
+                }),
+            ('no distribution', {
+                'test_distribution': None,
+                }),
+            ]
+
     def test_emits_changes_file_path_debug_message(self):
         """ Should emit debug message for changes file path. """
         self.test_args['debug'] = True
@@ -817,8 +867,9 @@ class verify_files_TestCase(
     def test_calls_parse_changes_with_changes_files(self):
         """ Should call `parse_changes` with changes file. """
         dput.dput.verify_files(**self.test_args)
-        dput.dput.parse_changes.assert_called_with(
-                self.changes_file_double.fake_file)
+        file_double = self.changes_file_double
+        with open(file_double.path, encoding='UTF-8') as expected_file:
+            dput.dput.parse_changes.assert_called_with(expected_file)
 
     def test_calls_check_upload_variant_with_changes_document(self):
         """ Should call `check_upload_variant` with changes document. """
@@ -1083,6 +1134,40 @@ class verify_files_TestCase(
         expected_result = self.expected_files_to_upload
         self.assertEqual(expected_result, set(result))
 
+
+class verify_files_UnusualPreferredEncodingTestCase(
+        testscenarios.WithScenarios,
+        verify_files_BaseTestCase):
+    """
+    Test cases for `verify_files` function when preferred encoding is unusual.
+    """
+
+    locale_getpreferredencoding_return_value = "ANSI_X3.4-1968"
+
+    scenarios = [
+            ('default', {}),
+            ]
+
+    def setUp(self):
+        """ Set up test fixtures. """
+        patch_locale_getpreferredencoding(self)
+        super().setUp()
+
+        set_changes_file_scenario(self, 'exist-needs-utf8')
+        self.test_args.update(dict(
+                changes_file_directory=os.path.dirname(
+                    self.changes_file_double.path),
+                changes_file_name=os.path.basename(
+                    self.changes_file_double.path),
+                ))
+
+    def test_calls_parse_changes_with_changes_files(self):
+        """ Should call `parse_changes` with changes file. """
+        dput.dput.verify_files(**self.test_args)
+        file_double = self.changes_file_double
+        expected_file = open(file_double.path, encoding='UTF-8')
+        dput.dput.parse_changes.assert_called_with(expected_file)
+
 
 class guess_upload_host_TestCase(
         testscenarios.WithScenarios,
@@ -1110,6 +1195,12 @@ class guess_upload_host_TestCase(
                         Lorem ipsum dolor sit amet
                     """)),
                 }),
+            ('needs-utf8 no-distribution', {
+                'fake_file': io.StringIO(textwrap.dedent("""\
+                    Files:
+                        Lórem ipsüm dolôr sìt āmet
+                    """)),
+                }),
             ]
 
     scenarios = [
@@ -1152,12 +1243,21 @@ class guess_upload_host_TestCase(
                 'config_default_default_host_main': "consecteur",
                 'expected_host': "consecteur",
                 }),
+            ('unusual-preferred-encoding no-distribution', {
+                'locale_preferredencoding_return_value': "ANSI_X3.4-1968",
+                'changes_file_scenario_name': "needs-utf8 no-distribution",
+                'config_scenario_name': "exist-simple",
+                'expected_host': "ftp-master",
+                }),
             ]
 
     def setUp(self):
         """ Set up test fixtures. """
         super().setUp()
         patch_system_interfaces(self)
+        if hasattr(self, 'locale_preferredencoding_return_value'):
+            patch_locale_getpreferredencoding(
+                    self, encoding=self.locale_preferredencoding_return_value)
 
         set_config(
                 self,
